pub fn coap_startup_with_feature_checks()Expand description
Initialize the CoAP library and additionally perform runtime checks to ensure that required
features (as enabled in Cargo.toml) are available and that the used DTLS library matches the
one that was determined during compile-time.
You should prefer using this function over coap_startup(), as without calling this function
some of the features enabled using the Cargo features may not actually be available.
Either this function or coap_startup() must be run once before any libcoap function is called.
If you are absolutely 100% certain that all features you require are always available (or are
prepared to deal with error return values/different behavior on your own if they aren’t), you
may use coap_startup() instead.